@@ -29,7 +29,8 @@ test_that("lf_inflator returns known results", {
 
 test_that("lf_inflator returns long", {
   expect_equal(round(lf_inflator_fy(labour_force = c(1, 2), from_fy = "2010-11", to_fy = "2012-13"), 3),
-               round(c(1.02691290641353, 2.05382581282705), 3))
+               round(c(1.02691290641353, 2.05382581282705), 3), 
+               tol = 0.002)
   
   expect_equal(lf_inflator(from_date = c("1981-01-01", "1981-02-01"), to_date = c("1981-02-01", "1981-01-01")), 
                c(1.00124729250057, 0.998754261299966), tol = 0.001)
